import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';

// Stores the locale id of the loaded resource
let resourceLocale = 'en-US';
// Convert JSON resource file data to Translations
function parseTranslations(fileData) {
    // Converts JSON file into JavaScript object and cast that to the type of the strongly typed translation
    let translations = JSON.parse(fileData).translations;
    return translations;
}
// Get a resource file URL
function getLanguageUrl(baseUrl, id) {
    return `${baseUrl}/${id}.json`;
}
function setCookie(name, value) {
    // Add language to the cookie
    // language=fi
    document.cookie = `${name}=${value}`;
}
function getCookie(name) {
    //console.log('getCookie');
    // cookie: language=fi; other=xxx
    // return: fi
    let tag = name + "=";
    let decodedCookie = decodeURIComponent(document.cookie);
    let values = decodedCookie.split(';');
    for (let value of values) {
        value = value.trim();
        if (value.indexOf(tag) == 0)
            return value.substring(tag.length, value.length);
    }
    return "";
}
// Load resources from the specific URL
function getTranslationsByUrl(url, id, setLocaleId = true) {
    return fetch(url)
        .then(response => {
        if (!response.ok)
            return null;
        return response.text();
    })
        .then((data) => {
        if (data && setLocaleId)
            resourceLocale = id;
        return parseTranslations(data);
    })
        .catch(() => null);
}
// Load resources matching the give language id. If not found, use the fallback ids.
function getTranslationsById(baseUrl, id, fallbacks, setLocaleId) {
    //console.log('getTranslationsById: ' + id);
    return getTranslationsByUrl(getLanguageUrl(baseUrl, id), id, setLocaleId).then(translations => {
        // If translations were found return it
        if (translations)
            return translations;
        // No translations were found. Try the parent language, if any.
        let parts = id.split('-');
        if (parts.length > 1) {
            // Try the parent id. For example de-DE -> de
            let parentId = parts[0];
            for (let i = 1; i < parts.length - 1; i++)
                parentId = parentId + '-' + parts[i];
            return getTranslationsById(baseUrl, parentId, fallbacks, setLocaleId);
        }
        else {
            // No more parents. Try the first language in the fallback list, if any.
            if (fallbacks.length > 0) {
                let id = fallbacks.shift();
                return getTranslationsById(baseUrl, id, fallbacks, setLocaleId);
            }
            else {
                // No more fallback languages. Return null (e.g., no translations found)
                return null;
            }
        }
    });
}
// Load resources matching the browser language(s)
function getTranslationsEx(baseUrl, options = null) {
    let ingoreCountry = false;
    let tryAllLanguages = true;
    let setLocaleId = true;
    let fallbackId = "en";
    let locale = null;
    let cookieName = null;
    if (options) {
        if (options.ingoreCountry != null)
            ingoreCountry = options.ingoreCountry;
        if (options.tryAllLanguages != null)
            tryAllLanguages = options.tryAllLanguages;
        if (options.setLocaleId != null)
            setLocaleId = options.setLocaleId;
        if (options.fallbackId)
            fallbackId = options.fallbackId;
        if (options.locale)
            locale = options.locale;
        if (options.cookieName)
            cookieName = options.cookieName;
    }
    if (cookieName)
        locale = getCookie(cookieName);
    // Get a copy of the browser languages
    let languages = [];
    if (locale)
        languages = locale.split(';');
    else if (!ingoreCountry)
        languages = [...navigator.languages];
    else {
        for (let language of navigator.languages) {
            let parts = language.split('-');
            let id = parts[0];
            if (languages.indexOf(id) == -1)
                languages.push(id);
        }
    }
    //console.log(languages);
    // Take the first id from the language list
    let id = languages.shift();
    // If only first should be tried clear the language list
    if (!tryAllLanguages)
        languages = [];
    // If a fallback has been specified and the language list does not contain it, add the fallback to the list
    if (fallbackId && (fallbackId !== id) && (languages.indexOf(fallbackId) == -1))
        languages.push(fallbackId);
    // Get the translations
    return getTranslationsById(baseUrl, id, languages, setLocaleId);
}
// Load resources matching the browser language(s)
function getTranslations(baseUrl, ingoreCountry = false, tryAllLanguages = true, setLocaleId = true, fallbackId = 'en', locale = null, cookieName = null) {
    let options = {
        ingoreCountry,
        tryAllLanguages,
        setLocaleId,
        fallbackId,
        locale,
        cookieName
    };
    return getTranslationsEx(baseUrl, options);
}
// Service that provides you the active resource locale
class LocaleService {
    get localeId() {
        return resourceLocale;
    }
}
LocaleService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: LocaleService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
LocaleService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: LocaleService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: LocaleService, decorators: [{
            type: Injectable
        }] });

/*
 * Public API Surface of angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LocaleService, getCookie, getTranslations, getTranslationsById, getTranslationsByUrl, getTranslationsEx, setCookie };
//# sourceMappingURL=soluling-angular.mjs.map
